%% Blocking Force Calculation of a MultilayerModel
% Created by Aleksandar Nacev


function ForceB = BlockingForce_MultiLayerModel (t,width,E,Kappa,L,v)

num = length(t); % number of layers
E = E./(1-v.*v); % Convert E for compressibility factor
Eo = E(1);
% N vector
n = E/(Eo); % ratio of materials for composite beam
width = n.*width;

% New numbers
a = t.*width; % Cross Sectional Area
I = (1/12)*width.*t.*t.*t; % Moment of Inertia

% Make Distance Matrix
for i = 1:num
    if i > 1
        D(1,i) = sum(t(1:i-1))+0.5*t(i);
    else
        D(1,i) = 0.5*t(i);
    end
end

% Calculate Neutral Axis
xNeutral = sum(a.*D)/sum(a);

% Calculate Equivalent Moment of Inertia
Ic = sum(I+a.*((D-xNeutral).^2));

% Calculate Blocking Force
ForceB = 1.5*(Eo*Ic*(Kappa))/(L);


end
